==> xl-react-components-0.16.62.tgz: package/tests/e2e/dsl/component/widget/widget-string.js <==
import {Action, ActionUtil, Expectation, WaitCondition} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';
import TestBindings from '../../common/test-bindings';

const sleepTime = 300;
const inputSelector = '.testComponent .xl-react-components.xl-react-widget-string input';
const textareaSelector = '.testComponent .xl-react-components.xl-react-widget-string textarea';

export const clearSelectedSize = () =>
    Action.click('.testBindings .change-size .xl-react-btn-close');

export const clearValue = () =>
    Action.click('.testComponent .xl-react-btn-close');

export const clickOnTextArea = () =>
    Action.click(textareaSelector);

export const expectClearIconPresent = () =>
    Expectation.displayed('.testComponent .xl-react-btn-close');

export const expectClearIconNotPresent = () =>
    Expectation.notDisplayed('.testComponent .xl-react-btn-close');

export const expectTextAreaPlaceholderToEqual = (placeholderValue) =>
    Expectation.attributeContainsValue(textareaSelector, 'placeholder', placeholderValue);

export const expectTextAreaContentToEqual = (content) =>
    Expectation.textEquals(textareaSelector, content);

export const hideChangedValue = () => {
    const action = () => XlComponent.clickOnLabel();
    const condition = () => WaitCondition.textEquals(textareaSelector, '*(changed) encrypted value*');
    ActionUtil.repeatAction(action, condition);
};

export const expectPlaceholderToEqual = (placeholderValue) =>
    Expectation.attributeContainsValue(inputSelector, 'placeholder', placeholderValue);

export const expectReadonlyInput = () =>
    Expectation.hasAttribute(inputSelector, 'readonly');

export const expectNotReadonlyInput = () =>
    Expectation.hasNoAttribute(inputSelector, 'readonly');

export const expectReadonlyTextArea = () =>
    Expectation.hasAttribute(textareaSelector, 'readonly');

export const expectNotReadonlyTextArea = () =>
    Expectation.hasNoAttribute(textareaSelector, 'readonly');

export const expectInputTypeToEqual = (type) =>
    Expectation.attributeContainsValue(inputSelector, 'type', type);

export const openSizeSelect = () => {
    const containerSelector = '.testBindings .change-size';
    const action = () => Action.click(`${containerSelector} .show-all`);
    const condition = () => WaitCondition.present(`${containerSelector} .resize-triggers`);
    return ActionUtil.repeatAction(action, condition);
};

export const openTypeSelect = () => {
    const containerSelector = '.testBindings .change-type';
    const action = () => Action.click(`${containerSelector} .show-all`);
    const condition = () => WaitCondition.present(`${containerSelector} .resize-triggers`);
    return ActionUtil.repeatAction(action, condition);
};

export const toggleSmallSize = () => {
    openSizeSelect();
    const suggestionOption = '.xl-react-autocomplete-suggestion:nth-child(3) div';
    Action.click(`.testBindings .change-size .xl-react-autocomplete-suggestion-list ${suggestionOption}`);
    return browser.driver.sleep(sleepTime);
};

export const toggleMediumSize = () => {
    openSizeSelect();
    const suggestionOption = '.xl-react-autocomplete-suggestion:nth-child(2) div';
    Action.click(`.testBindings .change-size .xl-react-autocomplete-suggestion-list ${suggestionOption}`);
    return browser.driver.sleep(sleepTime);
};

export const toggleLargeSize = () => {
    openSizeSelect();
    const suggestionOption = '.xl-react-autocomplete-suggestion:nth-child(1) div';
    Action.click(`.testBindings .change-size .xl-react-autocomplete-suggestion-list ${suggestionOption}`);
    browser.driver.sleep(sleepTime);
};

export const togglePassword = () =>
    TestBindings.toggleCheckbox('.testBindings input.password');

export const toggleEnumPassword = () =>
    Action.click('.testBindings .change-type input[value="password"');

export const toggleSearch = () => {
    openTypeSelect();
    const suggestionOption = '.xl-react-autocomplete-suggestion:nth-child(2) div';
    Action.click(`.testBindings .change-type .xl-react-autocomplete-suggestion-list ${suggestionOption}`);
    browser.driver.sleep(sleepTime);
};

export const toggleText = () =>
    Action.click('.testBindings .change-type input[value="text"');

export const setValue = (value) =>
    Action.typeText(inputSelector, value);

export const setTextAreaValue = (value) =>
    Action.typeText(textareaSelector, value);

const WidgetString = {
    ...XlComponent,
    clearSelectedSize,
    clearValue,
    clickOnTextArea,
    expectClearIconNotPresent,
    expectClearIconPresent,
    expectInputTypeToEqual,
    expectNotReadonlyInput,
    expectNotReadonlyTextArea,
    expectPlaceholderToEqual,
    expectReadonlyInput,
    expectReadonlyTextArea,
    expectTextAreaContentToEqual,
    expectTextAreaPlaceholderToEqual,
    hideChangedValue,
    openSizeSelect,
    setValue,
    setTextAreaValue,
    toggleLargeSize,
    toggleMediumSize,
    togglePassword,
    toggleEnumPassword,
    toggleSearch,
    toggleSmallSize,
    toggleText
};

export default WidgetString;
global.WidgetString = WidgetString;

==> xl-react-components-0.18.103.tgz: package/tests/e2e/dsl/component/widget/widget-string.js <==
import {Action, ActionUtil, Expectation, WaitCondition} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';
import TestBindings from '../../common/test-bindings';

const sleepTime = 300;
const componentSelector = '.testComponent .xl-react-components';
const inputSelector = `${componentSelector}.xl-react-widget-string input`;
const textareaSelector = `${componentSelector}.xl-react-widget-string textarea`;

export const clearSelectedSize = () =>
    Action.click('.testBindings .change-size .xl-react-btn-close');

export const clearValue = () =>
    Action.click('.testComponent .xl-react-btn-close');

export const clickOnTextArea = () =>
    Action.click(textareaSelector);

export const clickShowPasswordButton = () =>
    Action.click('.testComponent .xl-react-widget-reveal-password-icon');

export const expectClearIconPresent = () =>
    Expectation.displayed('.testComponent .xl-react-btn-close');

export const expectShowPasswordIconPresent = () =>
    Expectation.displayed('.testComponent .xl-react-widget-reveal-password-icon');

export const expectClearIconNotPresent = () =>
    Expectation.notDisplayed('.testComponent .xl-react-btn-close');

export const expectShowPasswordIconNotPresent = () =>
    Expectation.notDisplayed('.testComponent .xl-react-widget-reveal-password-icon');

export const expectTextAreaPlaceholderToEqual = (placeholderValue) =>
    Expectation.attributeContainsValue(textareaSelector, 'placeholder', placeholderValue);

export const expectFirstLineMonacoFieldHasText = (text) => {
    const firstLineSelector = `${componentSelector} .view-lines .view-line:nth-child(1) span span`;
    Expectation.textEquals(firstLineSelector, text);
};

export const expectMonacoFieldReadonly = () =>
    Expectation.attributeContainsValue(
        `${componentSelector} .xl-react-component-input-wrapper`, 'class', 'readonly');

export const expectMonacoFieldNotReadonly = () =>
    Expectation.attributeDoesntContainValue(
        `${componentSelector} .xl-react-component-input-wrapper`, 'class', 'readonly');

export const expectTextAreaContentToEqual = (content) =>
    Expectation.textEquals(textareaSelector, content);

export const expectInputContentToEqual = (content) =>
    Expectation.textEquals(inputSelector, content);

export const hideChangedValue = () => {
    const action = () => XlComponent.clickOnLabel();
    const condition = () => WaitCondition.textEquals(textareaSelector, '*(changed) encrypted value*');
    ActionUtil.repeatAction(action, condition);
};

export const expectPlaceholderToEqual = (placeholderValue) =>
    Expectation.attributeContainsValue(inputSelector, 'placeholder', placeholderValue);

export const expectReadonlyInput = () =>
    Expectation.hasAttribute(inputSelector, 'readonly');

export const expectNotReadonlyInput = () =>
    Expectation.hasNoAttribute(inputSelector, 'readonly');

export const expectReadonlyTextArea = () =>
    Expectation.hasAttribute(textareaSelector, 'readonly');

export const expectNotReadonlyTextArea = () =>
    Expectation.hasNoAttribute(textareaSelector, 'readonly');

export const expectInputTypeToEqual = (type) =>
    Expectation.attributeContainsValue(inputSelector, 'type', type);

export const openTypeSelect = () => TestBindings.openEnumSelection('type');

export const toggleSmallSize = () => TestBindings.openEnumAndSelect(3, 'size');

export const toggleMediumSize = () => TestBindings.openEnumAndSelect(2, 'size');

export const toggleLargeSize = () => TestBindings.openEnumAndSelect(1, 'size');

export const toggleDefaultView = () => TestBindings.openEnumAndSelect(1, 'view');

export const toggleMonacoView = () => TestBindings.openEnumAndSelect(2, 'view');

export const togglePassword = () =>
    TestBindings.toggleCheckbox('.testBindings input.password');

export const toggleEnumPassword = () =>
    Action.click('.testBindings .change-type input[value="password"');

export const toggleSearch = () => {
    openTypeSelect();
    const suggestionOption = '.xl-react-autocomplete-suggestion:nth-child(2) div';
    Action.click(`.testBindings .change-type .xl-react-autocomplete-suggestion-list ${suggestionOption}`);
    browser.driver.sleep(sleepTime);
};

export const toggleText = () =>
    Action.click('.testBindings .change-type input[value="text"');

export const setValue = (value) =>
    Action.typeText(inputSelector, value);

export const setTextAreaValue = (value) =>
    Action.typeText(textareaSelector, value);

const WidgetString = {
    ...XlComponent,
    clearSelectedSize,
    clearValue,
    clickOnTextArea,
    clickShowPasswordButton,
    expectClearIconNotPresent,
    expectClearIconPresent,
    expectFirstLineMonacoFieldHasText,
    expectMonacoFieldReadonly,
    expectMonacoFieldNotReadonly,
    expectShowPasswordIconPresent,
    expectInputContentToEqual,
    expectShowPasswordIconNotPresent,
    expectInputTypeToEqual,
    expectNotReadonlyInput,
    expectNotReadonlyTextArea,
    expectPlaceholderToEqual,
    expectReadonlyInput,
    expectReadonlyTextArea,
    expectTextAreaContentToEqual,
    expectTextAreaPlaceholderToEqual,
    hideChangedValue,
    setValue,
    setTextAreaValue,
    toggleDefaultView,
    toggleLargeSize,
    toggleMediumSize,
    toggleMonacoView,
    togglePassword,
    toggleEnumPassword,
    toggleSearch,
    toggleSmallSize,
    toggleText
};

export default WidgetString;
global.WidgetString = WidgetString;
